@@ -16,7 +16,7 @@
 ## along with this program; if not, a copy is available at
 ## https://www.R-project.org/Licenses/GPL-2
 
-stratrs <- function(y, C=floor(length(y)/2000))
+stratrs <- function(y, C=5)
 {
     strat <- unique(sort(y))
     rs <- integer(length(y))
